@@ -58,6 +58,7 @@ class AgentLifeCycle:
                                "cgs_diagnostics_ecs_api", "cgs_diagnostics_streamer_api", "cgs_bagger_server"]
     _docker_images = {}
     _docker_images["remote_intervention_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/remote_intervention_agent:latest"
+    _docker_images["kriya_watchdog"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/remote_intervention_agent:latest"
     _docker_images["cgs_diagnostics_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_agent:latest"
     _docker_images["cgs_diagnostics_ecs_api"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_api:latest"
     _docker_images["cgs_diagnostics_streamer_api"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_api:latest"
@@ -374,7 +375,10 @@ class AgentLifeCycle:
         if(args.config.is_ssh_enabled()):
             object._agent_run_options["remote_intervention_agent"]["volumes"] = {
                 args.config.config_path + "ssh/id_rsa": {"bind": "/root/.ssh/id_rsa", "mode": "rw"}}
-
+        object._agent_run_options["kriya_watchdog"] = {
+            "command": "python3 /home/watchdog.py","volumes": {
+            args.config.config_path + "kriya_logs/": {"bind": "/root/logs/", "mode": "rw"}, 
+            "/var/run/docker.sock/": {"bind": "/var/run/docker.sock/", "mode": "rw"}}}
         object._agent_run_options["rosbridge"] = {
             "command": "roslaunch rosbridge_server rosbridge_websocket.launch", "network_mode": "host"}
         object._agent_run_options["test"] = {"command": "bash"}
